@@ -34,8 +34,7 @@ _error_handler_async_local = error_handler_async(
 
 
 class HTTPAdapter(Adapter):
-    """HTTP 轮询适配器。使用 HTTP 轮询的方式与 mirai-api-http 沟通。
-    """
+    """HTTP 轮询适配器。使用 HTTP 轮询的方式与 mirai-api-http 沟通。"""
     host_name: str
     """mirai-api-http 的 HTTPAdapter Server 主机名。"""
     poll_interval: float
@@ -53,15 +52,12 @@ class HTTPAdapter(Adapter):
         single_mode: bool = False
     ):
         """
-        `verify_key: str` mirai-api-http 配置的认证 key，关闭认证时为 None。
-
-        `host: str` HTTP Server 的地址。
-
-        `port: int` HTTP Server 的端口。
-
-        `poll_interval: float = 1.` 轮询时间间隔，单位秒。
-
-        `single_mode: bool = False` 是否为单例模式。
+        Args:
+            verify_key: mirai-api-http 配置的认证 key，关闭认证时为 None。
+            host: HTTP Server 的地址。
+            port: HTTP Server 的端口。
+            poll_interval: 轮询时间间隔，单位秒。
+            single_mode: 是否为单例模式。
         """
         super().__init__(verify_key=verify_key, single_mode=single_mode)
 
@@ -231,14 +227,13 @@ class HTTPAdapter(Adapter):
         ) as client:
             if method == Method.GET or method == Method.RESTGET:
                 return await self._get(client, f'/{api}', params)
-            elif method == Method.POST or method == Method.RESTPOST:
+            if method == Method.POST or method == Method.RESTPOST:
                 return await self._post(client, f'/{api}', params)
-            elif method == Method.MULTIPART:
+            if method == Method.MULTIPART:
                 return await self._post_multipart(
                     client, f'/{api}', params['data'], params['files']
                 )
-            else:
-                return None
+            return None
 
     async def _background(self):
         """开始轮询。"""
