@@ -2,6 +2,7 @@
 """
 此模块提供 HTTP 回调适配器，适用于 mirai-api-http 的 webhook adapter。
 """
+import asyncio
 import logging
 from typing import Mapping, Optional, cast
 
@@ -22,8 +23,7 @@ class YiriMiraiJSONResponse(JSONResponse):
 
 
 class WebHookAdapter(Adapter):
-    """WebHook 适配器。作为 HTTP 服务器与 mirai-api-http 沟通。
-    """
+    """WebHook 适配器。作为 HTTP 服务器与 mirai-api-http 沟通。"""
     session: str
     """WebHook 不需要 session，此处为机器人的 QQ 号。"""
     route: str
@@ -41,16 +41,12 @@ class WebHookAdapter(Adapter):
         single_mode: bool = False
     ):
         """
-        `verify_key: str` mirai-api-http 配置的认证 key，关闭认证时为 None。
-
-        `route: str = '/'` 适配器的路由，默认在根目录上提供服务。
-
-        `extra_headers: Optional[Mapping[str, str]] = None` 额外请求头，与 mirai-api-http 的配置一致。
-
-        `enable_quick_response: bool = True` 是否启用快速响应，当与其他适配器混合使用时，
-            禁用可以提高响应速度。
-
-        `single_mode: bool = False` 是否启用单例模式。
+        Args:
+            verify_key: mirai-api-http 配置的认证 key，关闭认证时为 None。
+            route: 适配器的路由，默认在根目录上提供服务。
+            extra_headers: 额外请求头，与 mirai-api-http 的配置一致。
+            enable_quick_response: 是否启用快速响应，当与其他适配器混合使用时，禁用可以提高响应速度。
+            single_mode: 是否启用单例模式。
         """
         super().__init__(verify_key=verify_key, single_mode=single_mode)
         self.route = route
@@ -145,7 +141,8 @@ class WebHookAdapter(Adapter):
 
     async def handle_event(self, event):
         try:
-            await self.emit(event['type'], event)
+            tasks = await self.emit(event['type'], event)
+            await asyncio.gather(*tasks)
         except WebHookAdapter.QuickResponse as response:
             # 快速响应，直接返回。
             return response.data
